==> spring-security-oauth-2.0.6.RELEASE-sources.jar: org/springframework/security/oauth/consumer/client/OAuthRestTemplate.java <==
package org.springframework.security.oauth.consumer.client;

import org.springframework.http.client.ClientHttpRequestFactory;
import org.springframework.http.client.SimpleClientHttpRequestFactory;
import org.springframework.security.oauth.consumer.OAuthConsumerSupport;
import org.springframework.security.oauth.consumer.ProtectedResourceDetails;
import org.springframework.web.client.RestTemplate;

/**
 * Rest template that is able to make OAuth-authenticated REST requests with the credentials of the provided resource.
 *
 * @author Ryan Heaton
 */
public class OAuthRestTemplate extends RestTemplate {

  private final ProtectedResourceDetails resource;
  private OAuthConsumerSupport support = new CoreOAuthConsumerSupport();

  public OAuthRestTemplate(ProtectedResourceDetails resource) {
    this(new SimpleClientHttpRequestFactory(), resource);
  }

  public OAuthRestTemplate(ClientHttpRequestFactory requestFactory, ProtectedResourceDetails resource) {
    super();
    if (resource == null) {
      throw new IllegalArgumentException("An OAuth resource must be supplied.");
    }
    if (support == null) {
      throw new IllegalArgumentException("OAuth support must be supplied.");
    }

    this.resource = resource;
    setRequestFactory(requestFactory);
  }

  @Override
  public void setRequestFactory(ClientHttpRequestFactory requestFactory) {
    if (!(requestFactory instanceof OAuthClientHttpRequestFactory)) {
      requestFactory = new OAuthClientHttpRequestFactory(requestFactory, getResource(), getSupport());
    }
    super.setRequestFactory(requestFactory);
  }


  public ProtectedResourceDetails getResource() {
    return resource;
  }

  /**
   * The support logic to use.
   *
   * @return The support logic to use.
   */
  public OAuthConsumerSupport getSupport() {
    return support;
  }

  /**
   * The support logic to use.
   *
   * @param support The support logic to use.
   */
  public void setSupport(OAuthConsumerSupport support) {
    this.support = support;
  }

}

==> spring-security-oauth-2.5.1.RELEASE-sources.jar: org/springframework/security/oauth/consumer/client/OAuthRestTemplate.java <==
package org.springframework.security.oauth.consumer.client;

import org.springframework.http.client.ClientHttpRequestFactory;
import org.springframework.http.client.SimpleClientHttpRequestFactory;
import org.springframework.security.oauth.consumer.OAuthConsumerSupport;
import org.springframework.security.oauth.consumer.ProtectedResourceDetails;
import org.springframework.web.client.RestTemplate;

/**
 * Rest template that is able to make OAuth-authenticated REST requests with the credentials of the provided resource.
 *
 * <p>
 * @deprecated The OAuth 1.0 Protocol <a href="https://tools.ietf.org/html/rfc5849">RFC 5849</a> is obsoleted by the OAuth 2.0 Authorization Framework <a href="https://tools.ietf.org/html/rfc6749">RFC 6749</a>.
 *
 * @author Ryan Heaton
 */
@Deprecated
public class OAuthRestTemplate extends RestTemplate {

  private final ProtectedResourceDetails resource;
  private OAuthConsumerSupport support = new CoreOAuthConsumerSupport();

  public OAuthRestTemplate(ProtectedResourceDetails resource) {
    this(new SimpleClientHttpRequestFactory(), resource);
  }

  public OAuthRestTemplate(ClientHttpRequestFactory requestFactory, ProtectedResourceDetails resource) {
    super();
    if (resource == null) {
      throw new IllegalArgumentException("An OAuth resource must be supplied.");
    }
    if (support == null) {
      throw new IllegalArgumentException("OAuth support must be supplied.");
    }

    this.resource = resource;
    setRequestFactory(requestFactory);
  }

  @Override
  public void setRequestFactory(ClientHttpRequestFactory requestFactory) {
    if (!(requestFactory instanceof OAuthClientHttpRequestFactory)) {
      requestFactory = new OAuthClientHttpRequestFactory(requestFactory, getResource(), getSupport());
    }
    super.setRequestFactory(requestFactory);
  }


  public ProtectedResourceDetails getResource() {
    return resource;
  }

  /**
   * The support logic to use.
   *
   * @return The support logic to use.
   */
  public OAuthConsumerSupport getSupport() {
    return support;
  }

  /**
   * The support logic to use.
   *
   * @param support The support logic to use.
   */
  public void setSupport(OAuthConsumerSupport support) {
    this.support = support;
  }

}
